/*!**********************************************************************************
* 	Firmware para a placa de interface serial do projeto Expansion	
*	--------------------------------------------------------------------------------
*	Target: STR711 using the internal flash memory
*	Compiler/Toolchain: GNU with gcc 4.1.1 (WinARM 6/06)
*
*	Partly based on code from:
*	- Anglia Design (www.anglia-designs.com, Author: Spencer Oliver)
*	- STMicroelectronics (www.st.com)
*	- Yuri Tiomkin (www.tnkernel.org)
*	- STR71x Example Application by Martin Thomas, Kaiserlautern, Germany
*		http://www.siwawi.arubi.uni-kl.de/avr_projects/arm_projects
***********************************************************************************/

#include "71x_lib.h"
#include "vectors.h"
#include "GlobalVariables.h"
#include "Computer.h"
#include "Gps.h"


#define UART0_Rx_Pin (0x0001<<8)
#define UART0_Tx_Pin (0x0001<<9)

#define UART1_Rx_Pin (0x0001<<10)
#define UART1_Tx_Pin (0x0001<<11)

#define UART2_Rx_Pin (0x0001<<13)
#define UART2_Tx_Pin (0x0001<<14)

#define UART3_Rx_Pin (0x0001<<1)
#define UART3_Tx_Pin (0x0001<<0)

void initUART(UART_TypeDef *UARTx, u16 baudrate)
{
	
	if(UARTx == UART0)
	{
		GPIO_Config(GPIO0, UART0_Tx_Pin, GPIO_AF_PP);
		GPIO_Config(GPIO0, UART0_Rx_Pin, GPIO_IN_TRI_CMOS);
	}
	else if(UARTx == UART1)
	{
		GPIO_Config(GPIO0, UART1_Tx_Pin, GPIO_AF_PP);
		GPIO_Config(GPIO0, UART1_Rx_Pin, GPIO_IN_TRI_CMOS);
	}
	else if(UARTx == UART2)
	{
		GPIO_Config(GPIO0, UART2_Tx_Pin, GPIO_AF_PP);
		GPIO_Config(GPIO0, UART2_Rx_Pin, GPIO_IN_TRI_CMOS);
	}
	else if(UARTx == UART3)
	{
		GPIO_Config(GPIO0, UART3_Tx_Pin, GPIO_AF_PP);
		GPIO_Config(GPIO0, UART3_Rx_Pin, GPIO_IN_TRI_CMOS);
	}
	
	/*  Configure the UART X */
	UART_OnOffConfig(UARTx, ENABLE);      /*  Turn UART0 on */
	UART_FifoConfig(UARTx, DISABLE);      /*  Disable FIFOs */
	UART_FifoReset(UARTx, UART_RxFIFO);   /*  Reset the UART_RxFIFO */
	UART_FifoReset(UARTx, UART_TxFIFO );  /*  Reset the UART_TxFIFO */
	UART_LoopBackConfig(UARTx , DISABLE); /*  Disable Loop Back */
	/* Configure the UART0 as following:
	- Baudrate = baudrate 
	- No parity
	- 8 data bits
	- 1 stop bit */
	UART_Config( UARTx, baudrate, UART_NO_PARITY, UART_1_StopBits ,UARTM_8D );
	UART_RxConfig(UARTx ,ENABLE);
}

void initSystemFrequency(void)
{
	// use the PLL and configure the various clocks:
	/* RCCU peripheral configuration ------------------------------------------*/
	RCCU_Div2Config( ENABLE );                    // DIV2
	
	/*  Configure MCLK clock for the CPU, RCCU_DEFAULT = RCLK /1 */
	RCCU_MCLKConfig (RCCU_DEFAULT);  //Main system clock, to ARM & memory
	/*  Configure FCLK = RCLK /2 */
	RCCU_FCLKConfig ( RCCU_RCLK/2 ); //Clock to the fast peripherals (PCLK1)
	/*  Configure PCLK = RCLK /4 */
	RCCU_PCLKConfig ( RCCU_RCLK/2 );//Peripheral clock, to APB (PCLK2	)
	/*  Configure the PLL1 ( * 12 , / 2 ) */
	RCCU_PLL1Config ( RCCU_PLL1_Mul_24, RCCU_Div_1 );	
	/*  Wait PLL to lock */
	while( RCCU_FlagStatus( RCCU_PLL1_LOCK ) == RESET );	
	/*  Select PLL1_Output as RCLK clock */
	RCCU_RCLKSourceConfig (RCCU_PLL1_Output) ;
}

INLINE u8 test(void)
{	
	return 1;
}

int main (void)
{
	//Inicia os clocks para o sistema. DEVE ser a primeira coisa a ser feita.
	initSystemFrequency();
	
	initComputer();
	initGps();
	
	//inicia todo o sistema de gerência de interrupções
	EIC_IRQConfig(ENABLE);

	//Aguarda a requisição do computador de forma a dar um tempo para os sensores serem iniciados.
	//Envia o comando para o GPS parar de enviar dados no modo contínuo e ficar no modo escuta.
	while(!flagSend2Computer);
	flagSend2Computer = 0;
		
	while(1)
	{
		test();
	}
}
